package com.ruoyi.mall.service.impl;

import com.ruoyi.mall.domain.MallConfigType;
import com.ruoyi.mall.domain.Vo.SchoolTypeVO;
import com.ruoyi.mall.mapper.MallConfigTypeMapper;
import com.ruoyi.mall.service.IMallConfigTypeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 学校类型设置（综合类、理工类）Service业务层处理
 *
 * @author Lsm
 * @date 2023-10-18
 */
@Service
public class MallConfigTypeServiceImpl implements IMallConfigTypeService
{
    @Autowired
    private MallConfigTypeMapper mallConfigTypeMapper;

    /**
     * 查询学校类型设置（综合类、理工类）
     *
     * @param configTypeId 学校类型设置（综合类、理工类）主键
     * @return 学校类型设置（综合类、理工类）
     */
    @Override
    public MallConfigType selectMallConfigTypeByConfigTypeId(Long configTypeId)
    {
        return mallConfigTypeMapper.selectMallConfigTypeByConfigTypeId(configTypeId);
    }

    /**
     * 查询学校类型设置（综合类、理工类）列表
     *
     * @param mallConfigType 学校类型设置（综合类、理工类）
     * @return 学校类型设置（综合类、理工类）
     */
    @Override
    public List<MallConfigType> selectMallConfigTypeList(MallConfigType mallConfigType)
    {
        return mallConfigTypeMapper.selectMallConfigTypeList(mallConfigType);
    }

    /**
     * 新增学校类型设置（综合类、理工类）
     *
     * @param mallConfigType 学校类型设置（综合类、理工类）
     * @return 结果
     */
    @Override
    public int insertMallConfigType(MallConfigType mallConfigType)
    {
        return mallConfigTypeMapper.insertMallConfigType(mallConfigType);
    }

    /**
     * 修改学校类型设置（综合类、理工类）
     *
     * @param mallConfigType 学校类型设置（综合类、理工类）
     * @return 结果
     */
    @Override
    public int updateMallConfigType(MallConfigType mallConfigType)
    {
        return mallConfigTypeMapper.updateMallConfigType(mallConfigType);
    }

    /**
     * 批量删除学校类型设置（综合类、理工类）
     *
     * @param configTypeIds 需要删除的学校类型设置（综合类、理工类）主键
     * @return 结果
     */
    @Override
    public int deleteMallConfigTypeByConfigTypeIds(Long[] configTypeIds)
    {
        return mallConfigTypeMapper.deleteMallConfigTypeByConfigTypeIds(configTypeIds);
    }

    /**
     * 删除学校类型设置（综合类、理工类）信息
     *
     * @param configTypeId 学校类型设置（综合类、理工类）主键
     * @return 结果
     */
    @Override
    public int deleteMallConfigTypeByConfigTypeId(Long configTypeId)
    {
        return mallConfigTypeMapper.deleteMallConfigTypeByConfigTypeId(configTypeId);
    }

    /**
     * 学校类型列表
     * @return 结果
     */
    @Override
    public List<SchoolTypeVO> selectConfigTypeList() {
        return mallConfigTypeMapper.selectConfigTypeList();
    }
}
