package com.ruoyi.mall.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.mall.domain.MallConfigType;
import com.ruoyi.mall.service.IMallConfigTypeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 学校类型设置（综合类、理工类）Controller
 *
 * @author Lsm
 * @date 2023-10-18
 */
@RestController
@RequestMapping("/mall/mallConfigType")
public class MallConfigTypeController extends BaseController
{
    @Autowired
    private IMallConfigTypeService mallConfigTypeService;

    /**
     * 查询学校类型设置（综合类、理工类）列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallConfigType:list')")
    @GetMapping("/list")
    public TableDataInfo list(MallConfigType mallConfigType)
    {
        startPage();
        List<MallConfigType> list = mallConfigTypeService.selectMallConfigTypeList(mallConfigType);
        return getDataTable(list);
    }

    /**
     * 导出学校类型设置（综合类、理工类）列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallConfigType:export')")
    @Log(title = "学校类型设置（综合类、理工类）", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MallConfigType mallConfigType)
    {
        List<MallConfigType> list = mallConfigTypeService.selectMallConfigTypeList(mallConfigType);
        ExcelUtil<MallConfigType> util = new ExcelUtil<MallConfigType>(MallConfigType.class);
        util.exportExcel(response, list, "学校类型设置（综合类、理工类）数据");
    }

    /**
     * 获取学校类型设置（综合类、理工类）详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:mallConfigType:query')")
    @GetMapping(value = "/{configTypeId}")
    public AjaxResult getInfo(@PathVariable("configTypeId") Long configTypeId)
    {
        return AjaxResult.success(mallConfigTypeService.selectMallConfigTypeByConfigTypeId(configTypeId));
    }

    /**
     * 新增学校类型设置（综合类、理工类）
     */
    @PreAuthorize("@ss.hasPermi('mall:mallConfigType:add')")
    @Log(title = "学校类型设置（综合类、理工类）", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MallConfigType mallConfigType)
    {
        return toAjax(mallConfigTypeService.insertMallConfigType(mallConfigType));
    }

    /**
     * 修改学校类型设置（综合类、理工类）
     */
    @PreAuthorize("@ss.hasPermi('mall:mallConfigType:edit')")
    @Log(title = "学校类型设置（综合类、理工类）", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MallConfigType mallConfigType)
    {
        return toAjax(mallConfigTypeService.updateMallConfigType(mallConfigType));
    }

    /**
     * 删除学校类型设置（综合类、理工类）
     */
    @PreAuthorize("@ss.hasPermi('mall:mallConfigType:remove')")
    @Log(title = "学校类型设置（综合类、理工类）", businessType = BusinessType.DELETE)
	@DeleteMapping("/{configTypeIds}")
    public AjaxResult remove(@PathVariable Long[] configTypeIds)
    {
        return toAjax(mallConfigTypeService.deleteMallConfigTypeByConfigTypeIds(configTypeIds));
    }
}
